@@ -1,17 +1,17 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.017-5-gd9c33d7
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.018-7-g36c7381
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
     'Dist::Zilla::Role::PrereqSource';
 
-use List::Util 1.33 'none';
+use List::Util 1.33 qw(none any);
 use Git::Wrapper 0.035;
 use Try::Tiny;
 use Path::Tiny 0.048;
@@ -92,15 +92,17 @@ sub register_prereqs
 {
     my $self = shift;
 
-    return if none { /[^[:ascii:]]/ } @{$self->_contributors};
+    return if none { /[^[:ascii:]]/ } @{ $self->_contributors };
 
     my $prereqs = $self->zilla->prereqs;
-    my $perl_prereq = $prereqs->requirements_for(qw(runtime requires))
+    my $all_prereqs = $prereqs->requirements_for(qw(runtime requires))
         ->clone
         ->add_requirements($prereqs->requirements_for(qw(configure requires)))
         ->add_requirements($prereqs->requirements_for(qw(build requires)))
         ->add_requirements($prereqs->requirements_for(qw(test requires)))
-        ->as_string_hash->{perl};
+        ->as_string_hash;
+
+    my $perl_prereq = $all_prereqs->{perl};
 
     $self->log_debug([ 'found non-ascii characters in contributor names; perl prereq so far is %s',
         defined $perl_prereq ? $perl_prereq : 'unknown' ]);
@@ -108,15 +110,15 @@ sub register_prereqs
     $perl_prereq = version->parse($perl_prereq)->numify;
     return if "$perl_prereq" >= '5.008006';
 
+    # many Dist::Zilla-using distributions don't have an explicit minimum
+    # perl, but we know that Dist::Zilla doesn't work until 5.8.7
+    return if any { /^Dist::Zilla/ } keys %$all_prereqs;
+
+    # if dynamic_config is set, META.json will never be read so we're safe
+    return if $self->zilla->distmeta->{dynamic_config};
+
     # see https://github.com/makamaka/JSON-PP/pull/9 for for details
-    $self->log_debug('injecting JSON::PP prereq to deal with non-ascii content in META.json');
-    $self->zilla->register_prereqs(
-        {
-            phase => 'runtime',
-            type  => 'requires',
-        },
-        'JSON::PP' => '2.27300',
-    );
+    $self->log('Warning: distribution has non-ascii characters in contributor names. META.json will be unparsable on perls <= 5.8.6 when JSON::PP is lower than 2.27300');
 }
 
 # should not be called before the MetaProvider phase
@@ -249,7 +251,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -380,7 +382,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
