@@ -20,10 +20,12 @@ sub no_git_tempdir
 
     {
         my $in_git;
-        my $rootdir = Path::Tiny->rootdir;
         my $dir = $tempdir;
         my $count = 0;
-        while ($dir ne $rootdir and $count < 100) {
+        while (not $dir->is_rootdir) {
+            # this should never happen.
+            do { diag "failed to detect that $dir is at the root?!"; last } if $dir eq $dir->parent;
+
             my $checkdir = path($dir, '.git');
             if (-d $checkdir) {
                 note "found $checkdir in $tempdir";
